@@ -20,6 +20,62 @@ namespace binder {
 using namespace ost;
 using namespace std;
 
+const char *Checks::chkJoin(Line *line, ScriptImage *img)
+{
+	if(line->argc)
+		return "join uses no keywords or arguments";
+
+	if(getMember(line))
+		return "join has no members";
+
+	return NULL;
+}	
+
+const char *Checks::chkStart(Line *line, ScriptImage *img)
+{
+        unsigned idx = 0;
+	const char *cp;
+
+	if(!stricmp(line->cmd, "connect"))
+		cp = "=session=caller=display=timeout=duration=tone";
+	else
+		cp = "=session=caller=display";
+
+        if(!useKeywords(line, cp))
+                return "invalid keyword used for start";
+
+        if(!getOption(line, &idx))
+                return "no dial command specified";
+
+        if(!getOption(line, &idx))
+                return "no script specified";
+
+	while(NULL != (cp = getOption(line, &idx)))
+	{
+		if(*cp != '&' && *cp != '%')
+			return "remaining arguments must be variables";
+	}
+
+        return NULL;
+}
+
+const char *Checks::chkStop(Line *line, ScriptImage *img)
+{
+	if(getMember(line))
+		return "stop has no members";
+
+	if(hasKeywords(line))
+		return "stop uses no keywords";
+
+	if(line->argc < 1)
+		return "stop missing session id argument";
+
+	if(line->argc > 1)
+		return "stop only has one argument";
+
+	return NULL;
+}
+
 const char *Checks::chkEndinput(Line *line, ScriptImage *img)
 {
         if(getMember(line))
@@ -84,6 +140,9 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	const char *cp = getMember(line);
 	Name *scr = img->getCurrent();
 	BayonneDriver *driver;
+	const char *ext = strrchr(scr->filename, '.');
+	char dbuf[15];
+	char *sp;
 
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot register non-public script";
@@ -91,11 +150,29 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	if(cp)
 		++cp;
 
+	if(ext && !stricmp(ext, ".conf"))
+	{
+		if(cp)
+			return "cannot register to to alternate in config";
+
+		cp = strrchr(scr->filename, '/');
+		if(cp)
+			++cp;
+		else
+			cp = scr->filename;
+
+		setString(dbuf, sizeof(dbuf), scr->filename);
+		sp = strchr(dbuf, '.');
+		if(sp)
+			*sp = 0;
+		cp = dbuf;
+	}
+
 	driver = BayonneDriver::get(cp);
 		
 	if(!driver)
 	{
-		slog.warn("cannot register %s with %s", scr->name, cp);
+		slog.warn("cannot register %s", scr->name);
 		return "";
 	}
 	return driver->registerScript(img, line);
@@ -109,6 +186,10 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	char tag[65];
 	BayonneDriver *driver;
 	BayonneSession *s;
+	const char *ext = strrchr(scr->filename, '.');
+
+	if(ext && !stricmp(ext, ".conf"))
+		return "assign not used in config";
 
 	if(hasKeywords(line))
 		return "keywords not used for assign";
@@ -223,12 +304,23 @@ dnis:
 
 const char *Checks::chkSelect(Line *line, ScriptImage *img)
 {
-	const char *cp = getMember(line);
+	const char *cp = getMember(line), *sn;
 	Name *scr = img->getCurrent();
 	timeslot_t ts;
 	unsigned idx = 0, spid;
 	interface_t iface;
+	BayonneDriver *driver;
 	BayonneSession *session;
+	char *sp;
+	const char *ext = strrchr(scr->filename, '.');
+	const char *fn = strrchr(scr->filename, '/');
+	char buf[65];
+	char sbuf[96];
+
+	if(fn)
+		++fn;
+	else
+		fn = scr->filename;
 
 	if(hasKeywords(line))
 		return "keywords not used for select";
@@ -238,6 +330,46 @@ const char *Checks::chkSelect(Line *line, ScriptImage *img)
 
 	if(scr->access != ScriptInterp::scrPUBLIC)
 		return "cannot select from non-public script";	
+	
+	snprintf(sbuf, sizeof(sbuf), "select.%s", scr->name);
+
+	if(!stricmp(ext, ".conf"))
+	{
+		setString(buf, sizeof(buf), fn);
+		sp = strchr(buf, '.');		
+		if(sp)
+			*sp = 0;
+		driver = BayonneDriver::get(buf);
+		sn = strrchr(scr->name, ':');
+		if(sn)
+			++sn;
+		else
+			sn = scr->name;
+
+		if(!driver && stricmp(buf, "trunk"))
+			return "cannot select in this config";
+
+		if(!driver)
+		{
+			snprintf(sbuf, sizeof(sbuf), "select.%s", sn);
+			goto trunking;
+		}
+
+		cp = getOption(line, &idx);
+		if(!cp)
+			return "default server missing from select";
+
+		if(strchr(cp, '@'))
+			return "default server cannot include user";
+
+		snprintf(sbuf, sizeof(sbuf), "start-%s.%s", buf, sn);
+		img->setPointer(sbuf, scr);
+		img->addSelect(line);
+		return "";
+	}
+
+trunking:
+	img->setPointer(sbuf, scr);
 
 	if(cp && *cp == '.')
 		++cp;
