@@ -1319,7 +1319,7 @@ protected:
 	static Semaphore oink;	// the pig has been kicked!
 	static bool protocols;
 
-	BayonneSession *firstIdle, *lastIdle;
+	BayonneSession *firstIdle, *lastIdle, *highIdle;
 	BayonneMsgport *msgport;
 	BayonneDriver *nextDriver;
 	const char *name;
@@ -1348,6 +1348,12 @@ protected:
 	 */
 	virtual void stopDriver(void);
 
+	/**
+	 * Relist idle drivers on high idle list, for drivers which do
+	 * highwater marking allocation.
+	 */
+	void relistIdle(void);
+
 public:
 	/**
 	 * Create a driver instance.
