@@ -42,7 +42,6 @@ typedef struct
 
 static slot_t *slot;
 static int pid = 0;
-static int pri = 1;
 static bool err = false;
 static int buffers = 1024;
 static socklen_t blen = sizeof(buffers);
@@ -80,14 +79,14 @@ RETSIGTYPE child(int signo)
 	while((pid = wait3(&status, WNOHANG, 0)) > 0)
 	{
 		count = 0;
-		while(count < slots)
+		while(count < (unsigned)slots)
 		{
 			if(slot[count].pid == pid)
 				break;
 			++count;
 		}
 
-		if(count == slots)
+		if(count == (unsigned)slots)
 		{
 			if(err)
 				fprintf(stderr, "libexec exiting; unknown pid=%d\n", pid);
@@ -115,7 +114,7 @@ static void stop(void)
 	if(!slot || !slots)
 		return;
 
-	while(count < slots)
+	while(count < (unsigned)slots)
 	{
 		if(slot[count].pid)
 			kill(slot[count].pid, SIGTERM);
@@ -143,7 +142,7 @@ void BayonneSysexec::run(void)
 	char *tok;
 	const char *cp, *tsid, *cmd, *value;
 	char *var;
-	int pid, reason, size;
+	int pid, size;
 	
 	for(;;)
 	{
@@ -269,7 +268,6 @@ var:
                 {
                         event.id = ARGS_LIBEXEC;
                         event.libexec.tid = tsid;
-post:
                         if(!s->postEvent(&event))
 				slog.error("libexec unknown transaction; tsid=%s", tsid);
                         else
@@ -321,11 +319,7 @@ void BayonneSysexec::readline(char *buf, unsigned max)
 void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const char *modpath)
 {
 	char buf[LIBEXEC_BUFFER];
-	int len;
 	int fd = dup(2);
-	char *p;
-	unsigned ts;
-	long opt;
 	char path[512];
 	char cwd[512];
 	char *argv[8];
@@ -466,7 +460,7 @@ bool BayonneSysexec::create(BayonneSession *s)
 		lib += 9; 
 
 	s->newTid();
-	snprintf(buf, sizeof(buf), "%04d+%08lx %s", 
+	snprintf(buf, sizeof(buf), "%04d+%08x %s", 
 		s->getSlot(), s->newTid(), lib);
 	write(iopair[1], buf, sizeof(buf));
 	return true;
