@@ -266,7 +266,7 @@ void BayonneSession::libWrite(const char *str)
 	size_t len = strlen(str);
 	if(state.pfd != PFD_INVALID)
 	{
-		if(::write(state.pfd, (char *)str, len) < len)
+		if(::write(state.pfd, (char *)str, len) < (ssize_t)len)
 		{
 			::close(state.pfd);
 			state.pfd = PFD_INVALID;
@@ -297,7 +297,7 @@ uint32 BayonneSession::newTid(void)
 	}
 
 	state.pid = 0;
-	snprintf(var_tid, sizeof(var_tid), "%04d+%08lx", timeslot, ++tseq);
+	snprintf(var_tid, sizeof(var_tid), "%04d+%08x", timeslot, ++tseq);
 	return tseq;
 }
 
@@ -343,14 +343,14 @@ const char *BayonneSession::getExternal(const char *id)
 		{
 			tmp = getTemp();
 			time(&now);
-			snprintf(tmp, 16, "%08x-%04x", now, timeslot); 
+			snprintf(tmp, 16, "%08lx-%04x", now, timeslot); 
 			return tmp;
 		}			
 		else if(!stricmp(id, "mid"))
 		{
 			tmp = getTemp();
 			time(&now);
-			snprintf(tmp, 24, "%08x-%04x.%s", now, timeslot, audio.libext);
+			snprintf(tmp, 24, "%08lx-%04x.%s", now, timeslot, audio.libext);
 			return tmp;
 		}		
 		else if(!stricmp(id, "libext"))
@@ -409,7 +409,7 @@ const char *BayonneSession::getExternal(const char *id)
 			time(&now);
 			now -= starttime;
 
-			snprintf(var_duration, sizeof(var_duration), "%d:%02d:%02d",
+			snprintf(var_duration, sizeof(var_duration), "%ld:%02ld:%02ld",
 				now / 3600, (now / 60) % 60, now % 60);
 
 			return var_duration;
@@ -446,8 +446,9 @@ const char *BayonneSession::getExternal(const char *id)
 				return "isdn";
 			case IF_INET:
 				return "inet";
+			default:
+				return "none";
 			}
-			return "none";
 		}
 		else if(!stricmp(id, "bridge"))
 		{
@@ -458,8 +459,9 @@ const char *BayonneSession::getExternal(const char *id)
 			case BR_SOFT:
 			case BR_GATE:
 				return "soft";
+			default:
+				return "none";
 			}
-			return "none";
 		}
 		else if(!stricmp(id, "encoding"))
 			return audioEncoding();
@@ -468,7 +470,7 @@ const char *BayonneSession::getExternal(const char *id)
 		else if(!stricmp(id, "framing"))
 		{
 			tmp = getTemp();
-			snprintf(tmp, 10, "%d", audioFraming());
+			snprintf(tmp, 10, "%ld", (long)audioFraming());
 			return tmp;
 		}
 		return NULL;
@@ -516,7 +518,6 @@ const char *BayonneSession::getGlobal(const char *id)
 {
         char idg[64];
         Symbol *sym;
-        bool rtn = true;
 	const char *cp;
 
         if(!globalSyms)
@@ -1137,7 +1138,6 @@ void BayonneSession::disableDTMF(void)
 void BayonneSession::check(void)
 {
 	Line *line = getLine();
-	Name *scr = getName();
 
         if(state.menu)
         {
