@@ -39,9 +39,9 @@ static Keydata::Define driver[] = {
 	{NULL, NULL}};
 
 #ifdef  WIN32
-#define KEYS    "/bayonne/voicetronix"
+#define KEYS    "/bayonne/sangoma"
 #else
-#define KEYS    "/bayonne/driver/voicetronix"
+#define KEYS    "/bayonne/driver/sangoma"
 #endif
 
 Driver Driver::sangoma;
