@@ -51,7 +51,9 @@ static Keydata::Define driver[] = {
 	{"jitter", "2"},
 	{"filler", "false"},
 	{"urlprefix", "sip:"},
+	{"immediate", "yes"},
 	{"peering", "friend"},	// default registration type
+	{"starting", "delayed"},
 #ifdef	WIN32		// use localhost default if not in conf for w32
 	{"interface", "127.0.0.1:5070"},
 #endif
@@ -132,7 +134,8 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	{
 		gethostname(buf, sizeof(buf) - 1);
 		InetAddress host(buf);
-		snprintf(buf, sizeof(buf), "%s:5060", inet_ntoa(host.getAddress()));
+		snprintf(buf, sizeof(buf), "%s:5060", 
+			inet_ntoa(host.getAddress()));
 		setValue("interface", buf);
 		cp = getLast("interface");
 	}
@@ -152,6 +155,21 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 		rtp_port = atoi(cp);
 
 	silence = atoi(getLast("silence"));
+
+	cp = getLast("immediate");
+	send_immediate = false;
+
+	switch(*cp)
+	{
+	case 'y':
+	case 'Y':
+	case 't':
+	case 'T':
+	case '1':
+		send_immediate = true;
+		break;
+	}
+
 	cp = getLast("inband");
 
 	dtmf_inband = true;
@@ -190,6 +208,21 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	data_negotiate = atoi(getLast("payload"));
 	dtmf_negotiate = 0;
 
+	starting = START_DELAYED;
+
+	cp = getLast("starting");
+	switch(*cp)
+	{
+	case 'i':
+	case 'I':
+		starting = START_IMMEDIATE;
+		break;
+	case 'a':
+	case 'A':
+		starting = START_ACTIVE;
+		break;
+	}
+
 	cp = getLast("dtmf");
 	if(cp)
 		dtmf_negotiate = atoi(cp);
@@ -429,6 +462,14 @@ void Driver::startDriver(void)
 	Thread::start();
 	Thread::sleep(100);
 	BayonneDriver::startDriver();	
+
+	switch(starting)
+	{
+	case START_DELAYED:
+		relistIdle();
+	default:
+		break;
+	}
 }
 
 void Driver::stopDriver(void)
@@ -551,6 +592,7 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
         const char *cp = ScriptChecks::findKeyword(line, "timeout");
 	const char *lcp;
 	char buf[1024];
+	char nbuf[32];
 	unsigned len, pos;
 	char *p;
 	char *uri;
@@ -753,6 +795,18 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(p && !stricmp(p, ":5060"))
 		*p = 0;
 	img->setPointer(buf, reg);
+	p = strchr(buf, ':');
+	if(p)
+		*p = 0;
+	InetAddress host(buf + 4);
+	if(p)
+		*p = ':';
+	else
+		p = "";
+
+	snprintf(nbuf, sizeof(nbuf), "sip.%s%s",
+		inet_ntoa(host.getAddress()), p);
+	img->setPointer(nbuf, reg);
 
 	snprintf(buf, sizeof(buf), "sipreg.%d", reg->regid);
 	img->setPointer(buf, reg);
