@@ -16,6 +16,29 @@
 
 #include "module.h"
 
+#ifndef	WIN32
+#include "private.h"
+
+#include <sys/types.h>
+#include <sys/param.h>
+#ifdef HAVE_SYS_MOUNT_H
+#include <sys/mount.h>
+#endif
+#ifdef HAVE_SYS_STATVFS_H
+#include <sys/statvfs.h>
+#endif
+#ifdef HAVE_SYS_VFS_H
+#include <sys/vfs.h>
+#endif
+
+#ifdef HAVE_SYS_STATVFS_H
+#define STATFS statvfs
+#else
+#define STATFS statfs
+#endif
+
+#endif
+
 namespace module {
 using namespace ost;
 using namespace std;
@@ -37,6 +60,7 @@ void Session::help(void)
 	*tcp() << "nomon timeslots.. - disable state monitoring" << endl;
         *tcp() << "reg - display protocol registrations" << endl;
 	*tcp() << "reload - reload script configuration" << endl;
+	*tcp() << "diskstat - show disk status" << endl;
 	*tcp() << "shutdown - shutdown server" << endl;
 	*tcp() << "spans - list active spans in server" << endl;
 	*tcp() << "start dial script [num [cid]] - start a script running" << endl;
@@ -300,6 +324,65 @@ void Session::drivers(char **list)
 	}
 }
 
+void Session::diskstat(char **list)
+{
+    char lr[80];
+    char path[256];
+    char label[256];
+#ifndef	WIN32
+    struct STATFS fs;
+    unsigned long long bfree, bsize;
+#else
+    ULARGE_INTEGER bavail, btotal, bfree;
+#endif
+
+    while(*list)
+    {
+	strcpy(path,*list);
+	strcpy(label,*list);
+	if(stricmp(label, "datafiles")==0) {
+		if (getenv("SERVER_PREFIX")) {
+			strcpy(path,getenv("SERVER_PREFIX")); 
+		}
+	}
+	if(stricmp(*list, "prompts")==0) {
+		if (getenv("SERVER_PROMPTS")) {
+			strcpy(path,getenv("SERVER_PROMPTS")); 
+		}
+	}
+	if(stricmp(*list, "scripts")==0) {
+		if (getenv("SERVER_SCRIPTS")) {
+			strcpy(path,getenv("SERVER_SCRIPTS"));
+		}
+	}
+	if(stricmp(*list, "libexec")==0) {
+		if (getenv("SERVER_LIBEXEC")) {
+			strcpy(path,getenv("SERVER_LIBEXEC")); 
+		}
+	}
+
+#ifdef	WIN32			
+	GetDiskFreeSpaceEx(path, &bavail, &btotal, &bfree);
+	snprintf(lr, sizeof(lr), "%-15s %llu", label, bavail);
+#else
+	if (0 == STATFS(path,&fs)) {
+    	    bfree = fs.f_bfree;
+    	    bsize = fs.f_bsize;
+    	    snprintf(lr, sizeof(lr), "%-15s %llu",label,  bfree * bsize);
+	    *tcp() << lr << endl;
+	} else {
+	    snprintf(lr, sizeof(lr), "%-15s %-15s","*** error in label", path);
+	    *tcp() << lr << endl;
+	}
+#endif
+	
+	++list;
+    }
+
+	return;
+	*tcp() << "*** Invalid label" << endl;	
+}
+
 void Session::run(void)
 {
 	Event event;
@@ -520,6 +603,14 @@ void Session::run(void)
 				Session::uptime();
 			else if(!stricmp(*argv, "reload"))
 				Bayonne::reload();
+			else if(!stricmp(*argv, "diskstat")) {
+			    if(!argv[1])
+			    {
+				*tcp() << "*** disk label missing" << endl;
+				goto skip;
+			    }
+				diskstat(&argv[1]);
+			}	
 			else if(!stricmp(*argv, "help"))
 				help();
 			else if(!stricmp(*argv, "shutdown"))
