@@ -78,9 +78,10 @@ bool Methods::scrTransfer(void)
 		audio.tone = new DTMFTones(state.tone.digits, 20000, getToneFraming(), driver->getInterdigit());
 		setState(STATE_TONE);
 		return false;
+	default:
+		error("not-supported");
+		return true;
 	}
-	error("not-supported");
-	return true;
 }
 
 
@@ -651,7 +652,7 @@ bool Methods::scrSync(void)
 
 	time(&now);
 	now -= starttime;
-	if(now >= state.timeout / 1000)
+	if(now >= (time_t)(state.timeout / 1000))
 		state.timeout = 0;
 	else
 		state.timeout -= (timeout_t)(now * 1000l);
@@ -894,7 +895,6 @@ bool Methods::scrCopy(void)
 
 bool Methods::scrBuild(void)
 {
-	unsigned count = 0;
 	const char *cp, *dp;
 	Audio::Info info;
 	char buf[MAX_PATHNAME];
@@ -936,7 +936,6 @@ bool Methods::scrBuild(void)
 
 bool Methods::scrPrompt(void)
 {
-	unsigned count = 0;
 	const char *cp = getMember();
 
 	if(cp && stricmp(translator->getId(), cp))
@@ -1112,7 +1111,6 @@ bool Methods::scrAppend(void)
 
 bool Methods::scrPlay(void)
 {
-	unsigned count = 0;
 	const char *cp = getMember();
 
         if(cp && stricmp(translator->getId(), cp))
@@ -1257,7 +1255,7 @@ error:
 	}
 	if(*cp != '/' && cp[1] != ':')
 	{
-		snprintf(fbuf, sizeof(fbuf), "%s/%s", keypaths.getLast("datafiles"));
+		snprintf(fbuf, sizeof(fbuf), "%s/%s", keypaths.getLast("datafiles"), cp);
 		cp = fbuf;
 	}
 	Bayonne::commit(sym, cp);
