@@ -15,9 +15,13 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include "bayonne.h"
+#include <cc++/process.h>
+#include <cc++/slog.h>
 
 #ifdef	WIN32
+#ifdef	_DEBUG
 #define	HAVE_TESTING
+#endif
 #else
 #include "private.h"
 #endif
@@ -36,6 +40,30 @@
 #define	SCRIPT_EXTENSIONS ".sh.py.pl.php"
 #endif
 
+#if defined(_MSC_VER) && _MSC_VER >= 1300
+#if defined(_WIN64_) || defined(__WIN64__)
+#define RLL_SUFFIX ".x64"
+#elif defined(_M_IX86)
+#define RLL_SUFFIX ".x86"
+#else
+#define RLL_SUFFIX ".xlo"
+#endif
+#endif
+
+#if defined(__MINGW32__) | defined(__CYGWIN32__)
+#define RLL_SUFFIX ".dso"
+#endif
+
+#ifdef  W32
+#ifndef RLL_SUFFIX
+#define RLL_SUFFIX ".rll"
+#endif
+#endif
+
+#ifndef RLL_SUFFIX
+#define RLL_SUFFIX ".dso"
+#endif
+
 namespace server {
 using namespace ost;
 using namespace std;
@@ -112,6 +140,21 @@ public:
 	~CopyThread();
 };
 
+class WriteThread : public ScriptThread
+{
+private:
+	char text[512];
+	char path[MAX_PATHNAME];
+	const char *cp;
+	FILE *fp;
+
+public:
+	WriteThread(ScriptInterp *interp, const char *from);
+	~WriteThread();
+
+	void run(void);
+};
+
 class PositionProperty : public ScriptProperty, public Audio
 {
 public:
@@ -147,7 +190,6 @@ class Runtime : public ScriptRuntime, public Bayonne
 protected:
         unsigned long getTrapMask(const char *trapname);
 
-	static bool testBinding(ScriptInterp *interp, const char *v);
 	static bool testFile(ScriptInterp *interp, const char *v);
 	static bool testDir(ScriptInterp *interp, const char *v);
 	static bool testTimeslot(ScriptInterp *interp, const char *v);
@@ -159,10 +201,6 @@ protected:
 public:
 	static void process(void);
 
-	static bool startDriver(BayonneDriver *d, const char *name, const char *dial, const char *caller, const char *display);
-
-	static bool startSelect(const char *name, const char *dial, const char *caller, const char *display);
-
 	static bool command(char *line);
 
 	const char *getExternal(const char *opt);
@@ -194,9 +232,10 @@ public:
 	bool scrPath(void);
 	bool scrRead(void);
 	bool scrRoute(void);
+	bool scrWrite(void);
 	bool scrErase(void);
-	bool scrLink(void);
 	bool scrMove(void);
+	bool scrLink(void);
 	bool scrCopy(void);
 	bool scrTimeslot(void);
 	bool scrPosition(void);
@@ -219,14 +258,14 @@ public:
 	bool scrDTMF(void);
 	bool scrMF(void);
 	bool scrTransfer(void);
-	bool scrBind(void);
 };
 
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
-	const char *chkEndinput(Line *line, ScriptImage *img);
+        const char *chkEndinput(Line *line, ScriptImage *img); 
 	const char *chkBGM(Line *line, ScriptImage *img);
+	const char *chkWrite(Line *line, ScriptImage *img);
 	const char *chkList(Line *line, ScriptImage *img);
 	const char *chkConfig(Line *line, ScriptImage *img);
 	const char *chkPaths(Line *line, ScriptImage *img);
@@ -254,15 +293,16 @@ public:
 	const char *chkTransfer(Line *line, ScriptImage *img);
 	const char *chkChildSignal(Line *line, ScriptImage *img);
 	const char *chkDialer(Line *line, ScriptImage *img);
-	const char *chkBind(Line *line, ScriptImage *img);
 };
 
 extern Runtime runtime;
 extern Keydata keypaths;
 extern Keydata keyserver;
 extern Keydata keyengine;
-extern Keydata keyprotocols;
 extern Keydata keyoptions;
+extern BayonneConfig keylibexec;
+extern BayonneConfig keysmtp;
+extern BayonneConfig keyurl;
 
 extern TimeslotProperty typeTimeslot;
 extern PositionProperty typePosition;
